weaviate.collections
====================

.. automodule:: weaviate.collections
   :members:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   weaviate.collections.aggregations
   weaviate.collections.backups
   weaviate.collections.batch
   weaviate.collections.classes
   weaviate.collections.cluster
   weaviate.collections.collection
   weaviate.collections.collections
   weaviate.collections.config
   weaviate.collections.data
   weaviate.collections.grpc
   weaviate.collections.queries
   weaviate.collections.tenants


weaviate.collections.aggregate
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.collections.aggregate
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

weaviate.collections.filters
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.collections.filters
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

weaviate.collections.generate
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.collections.generate
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

weaviate.collections.iterator
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.collections.iterator
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

weaviate.collections.orm
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.collections.orm
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

weaviate.collections.query
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: weaviate.collections.query
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
